window.Gleam.initSearch([{"doc":"htmz","title":"htmz","content":"# htmz\n\n[![Package Version](https://img.shields.io/hexpm/v/htmz)](https://hex.pm/packages/htmz)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/htmz/)\n\n## Quick start\n\n```sh\ngleam test  # Run the tests\ngleam shell # Run an Erlang shell\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add htmz\n```\n\nIts documentation can be found at &lt;https://hexdocs.pm/htmz&gt;.\n\n## Usage\n\n### Examples\n\n```gleam\nimport htmz.{Html, Title, Head, Body, Div} as z\nimport gleam/io\n\npub fn main() {\n  let html =\n    Html\n    |&gt; z.child(\n      Body\n      |&gt; z.child(\n        Div\n        |&gt; z.text(&quot;Hello World&quot;),\n      ),\n    )\n\n   html\n   |&gt; z.to_string()\n   |&gt; io.debug()\n}\n```\n\n```gleam\nfn nav(inner: Htmz) -&gt; Htmz {\n  Z(&quot;.admins&quot;)\n  |&gt; z.children([\n    Header\n    |&gt; z.children([\n      H2\n      |&gt; z.text(&quot;Administratorzy&quot;),\n      Menu\n      |&gt; z.class(&quot;sub-menu&quot;)\n      |&gt; z.hx_target(&quot;#admins-main&quot;)\n      |&gt; z.hx_push_url(&quot;true&quot;)\n      |&gt; z.hx_indicator(&quot;#indicator&quot;)\n      |&gt; z.hx_sync(&quot;closest menu:replace&quot;)\n      |&gt; z.children([\n        Li\n        |&gt; z.child(\n          Button\n          |&gt; z.hx_get(&quot;/admin/admins&quot;)\n          |&gt; z.text(&quot;Lista&quot;),\n        ),\n        Li\n        |&gt; z.child(\n          Button\n          |&gt; z.hx_get(&quot;/admin/admins/new&quot;)\n          |&gt; z.text(&quot;Dodaj&quot;),\n        ),\n      ]),\n    ]),\n    Z(&quot;article#admins-main&quot;)\n    |&gt; z.child(inner),\n  ])\n}\n```\n\n```gleam\n\npub fn main() {\n  let el = \n    Html\n    |&gt; z.children([\n      Head\n      |&gt; z.children([\n        Title\n        |&gt; z.text(&quot;Hello World&quot;),\n        Meta\n        |&gt; z.charset(&quot;utf-8&quot;),\n      ]),\n      Body\n      |&gt; z.children([\n        Menu\n        |&gt; z.children([\n          Li\n          |&gt; z.child(\n            A\n            |&gt; z.href(&quot;/about&quot;)\n            |&gt; z.text(&quot;About&quot;),\n          ),\n          Li\n          |&gt; z.child(\n            A\n            |&gt; z.href(&quot;/contact&quot;)\n            |&gt; z.text(&quot;Contact&quot;),\n          ),\n        ]),\n        Main\n        |&gt; z.children([\n          H1\n          |&gt; z.text(&quot;Hello World&quot;),\n        ]),\n      ]),\n    ])\n\n   el\n   |&gt; z.to_string()\n   |&gt; io.debug()\n}\n```\n\n### &quot;type=&quot; issue\n\nThe &quot;type&quot; is a keyword in gleam, so you can&#39;t use it as a field name. Use &quot;type_&quot; instead.\n\n```gleam\nInput\n|&gt; z.type_(&quot;text&quot;)\n```\n\n### &quot;Z&quot; element\n\nYou can use &quot;Z&quot; element to create any element using css selector notation\n\n```gleam\nZ(&quot;sl-button&quot;)\n|&gt; z.attr(&quot;variant&quot;, &quot;success&quot;)\n|&gt; z.label(&quot;Click me&quot;)\n```\n\n```gleam\nZ(&quot;.foo#bar[baz=qux]&quot;)\n// &lt;div class=&quot;foo&quot; id=&quot;bar&quot; baz=&quot;qux&quot;&gt;&lt;/div&gt;\n```\n\n```gleam\nZ(&quot;i.fa.fa-user&quot;)\n// &lt;i class=&quot;fa fa-user&quot;&gt;&lt;/i&gt;\n```\n\n```gleam\nZ(&quot;input#password-input.form-control[type=password][name=password]&quot;)\n// &lt;input id=&quot;name-input&quot; class=&quot;form-control&quot; type=&quot;text&quot; placeholder=&quot;Name&quot; /&gt;\n```\n\n### HTMX support\n\nAll [htmx](https://htmx.org) attributes are supported.\n\n```gleam\nButton\n|&gt; z.HxGet(&quot;/load-me&quot;)\n|&gt; z.HxSwap(&quot;outerHTML&quot;)\n|&gt; z.HxTrigger(&quot;load&quot;)\n```\n\n### Alpine.js support\n\nAll [Alpine.js](https://alpinejs.dev/) attributes are supported.\n\n```gleam\nDiv\n|&gt; z.x_data(&quot;{ username: &#39;calebporzio&#39; }&quot;)\n|&gt; z.children([\n  Text(&quot;Username: &quot;),\n  Strong\n  |&gt; z.x_text(&quot;username&quot;),\n])\n```\n\n### Inserting text\n\nText is just a Text node but it has a value parameter. You can insert text nodes like this:\n\n```gleam\nDiv |&gt; z.child(Text(&quot;Hello World&quot;))\n```\n\nHowever, since this is a common operation, there is a `text(el: Htmz, value: String)` helper function:\n\n```gleam\nDiv |&gt; z.text(&quot;Hello World&quot;)\n```\n\nThe `z.text()` does exactly the same thing as the previous example.\n\n### Conditions\n\nUsing `case` you can conditionally render elements:\n\n```gleam\nDiv\n|&gt; z.children([\n  H3 \n  |&gt; z.text(&quot;Title&quot;),\n  case maybe_user {\n    Ok(user) -&gt; z.text(user.name)\n    Error(_) -&gt; z.text(&quot;No user&quot;)\n  }\n])\n```\n\nSometimes it&#39;s required to not insert anything. In this case, there is a special node: `Nothing`\n\n```gleam\nDiv\n|&gt; z.children([\n  H3 |&gt; z.text(&quot;Title&quot;),\n  case user \n    Ok(user) -&gt; z.text(user.name)\n    Error(_) -&gt; Nothing\n  }\n])\n```\n\nFor conditionally inserting attributes follow this pattern:\n\n```gleam\nDiv\n|&gt; case is_active {\n  True -&gt; z.class(_, &quot;active&quot;)\n  False -&gt; z.nothing(_)\n}\n|&gt; z.text(&quot;Hello World&quot;)\n```\n\n","url":"index.html"},{"doc":"htmz/selector_parser","title":"ParseResult","content":"pub type ParseResult {\n  ParseResult(tag_name: String, attrs: List(#(String, String)))\n}\n\nParseResult(tag_name: String, attrs: List(#(String, String)))\n\n\nSynonyms:\nhtmz/selector_parser.ParseResult\nhtmz/selector_parser ParseResult","url":"htmz/selector_parser.html#ParseResult"},{"doc":"htmz/selector_parser","title":"parse_css_selector","content":"pub fn parse_css_selector(\n  css_selector: String,\n) -&gt; Option(ParseResult)\n\nSynonyms:\nhtmz/selector_parser.parse_css_selector\nhtmz/selector_parser parse_css_selector","url":"htmz/selector_parser.html#parse_css_selector"},{"doc":"htmz/selector_parser","title":"htmz/selector_parser","content":"","url":"htmz/selector_parser.html"},{"doc":"htmz","title":"Attr","content":"pub type Attr {\n  Attr(name: String, value: String)\n}\n\nAttr(name: String, value: String)\n\n\nSynonyms:\nhtmz.Attr\nhtmz Attr","url":"htmz.html#Attr"},{"doc":"htmz","title":"Htmz","content":"pub type Htmz {\n  El(tag: String, attrs: List(Attr), children: List(Htmz))\n  Z(css_selector: String)\n  Text(text: String)\n  Nothing\n  Html\n  Head\n  Title\n  Body\n  Div\n  Form\n  Label\n  Input\n  A\n  Link\n  Meta\n  Abbr\n  Address\n  Article\n  Aside\n  Audio\n  B\n  Bdi\n  Bdo\n  Blockquote\n  Br\n  Button\n  Canvas\n  Caption\n  Cite\n  Code\n  Col\n  Colgroup\n  Data\n  Datalist\n  Dd\n  Del\n  Details\n  Dfn\n  Dialog\n  Dl\n  Dt\n  Em\n  Embed\n  Fieldset\n  Figcaption\n  Figure\n  Footer\n  H1\n  H2\n  H3\n  H4\n  H5\n  H6\n  Header\n  Hr\n  I\n  Iframe\n  Img\n  Ins\n  Kbd\n  Legend\n  Li\n  Main\n  Mark\n  Menu\n  Menuitem\n  Meter\n  Nav\n  Noscript\n  Object\n  Ol\n  Optgroup\n  Option\n  Output\n  P\n  Param\n  Picture\n  Pre\n  Progress\n  Q\n  Rp\n  Rt\n  Ruby\n  S\n  Samp\n  Script\n  Section\n  Select\n  Slot\n  Small\n  Source\n  Span\n  Strong\n  Sub\n  Summary\n  Sup\n  Table\n  Tbody\n  Td\n  Template\n  Textarea\n  Tfoot\n  Th\n  Thead\n  Time\n  Tr\n  Track\n  U\n  Ul\n  Var\n  Video\n  Wbr\n}\n\nEl(tag: String, attrs: List(Attr), children: List(Htmz))\n\n\nZ(css_selector: String)\n\n\nText(text: String)\n\n\nNothing\n\n\nHtml\n\n\nHead\n\n\nTitle\n\n\nBody\n\n\nDiv\n\n\nForm\n\n\nLabel\n\n\nInput\n\n\nA\n\n\nLink\n\n\nMeta\n\n\nAbbr\n\n\nAddress\n\n\nArticle\n\n\nAside\n\n\nAudio\n\n\nB\n\n\nBdi\n\n\nBdo\n\n\nBlockquote\n\n\nBr\n\n\nButton\n\n\nCanvas\n\n\nCaption\n\n\nCite\n\n\nCode\n\n\nCol\n\n\nColgroup\n\n\nData\n\n\nDatalist\n\n\nDd\n\n\nDel\n\n\nDetails\n\n\nDfn\n\n\nDialog\n\n\nDl\n\n\nDt\n\n\nEm\n\n\nEmbed\n\n\nFieldset\n\n\nFigcaption\n\n\nFigure\n\n\nFooter\n\n\nH1\n\n\nH2\n\n\nH3\n\n\nH4\n\n\nH5\n\n\nH6\n\n\nHeader\n\n\nHr\n\n\nI\n\n\nIframe\n\n\nImg\n\n\nIns\n\n\nKbd\n\n\nLegend\n\n\nLi\n\n\nMain\n\n\nMark\n\n\nMenu\n\n\nMenuitem\n\n\nMeter\n\n\nNav\n\n\nNoscript\n\n\nObject\n\n\nOl\n\n\nOptgroup\n\n\nOption\n\n\nOutput\n\n\nP\n\n\nParam\n\n\nPicture\n\n\nPre\n\n\nProgress\n\n\nQ\n\n\nRp\n\n\nRt\n\n\nRuby\n\n\nS\n\n\nSamp\n\n\nScript\n\n\nSection\n\n\nSelect\n\n\nSlot\n\n\nSmall\n\n\nSource\n\n\nSpan\n\n\nStrong\n\n\nSub\n\n\nSummary\n\n\nSup\n\n\nTable\n\n\nTbody\n\n\nTd\n\n\nTemplate\n\n\nTextarea\n\n\nTfoot\n\n\nTh\n\n\nThead\n\n\nTime\n\n\nTr\n\n\nTrack\n\n\nU\n\n\nUl\n\n\nVar\n\n\nVideo\n\n\nWbr\n\n\nSynonyms:\nhtmz.Htmz\nhtmz Htmz","url":"htmz.html#Htmz"},{"doc":"htmz","title":"accept","content":"pub fn accept(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.accept\nhtmz accept","url":"htmz.html#accept"},{"doc":"htmz","title":"accept_charset","content":"pub fn accept_charset(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.accept_charset\nhtmz accept_charset","url":"htmz.html#accept_charset"},{"doc":"htmz","title":"accesskey","content":"pub fn accesskey(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.accesskey\nhtmz accesskey","url":"htmz.html#accesskey"},{"doc":"htmz","title":"action","content":"pub fn action(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.action\nhtmz action","url":"htmz.html#action"},{"doc":"htmz","title":"alt","content":"pub fn alt(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.alt\nhtmz alt","url":"htmz.html#alt"},{"doc":"htmz","title":"async_attr","content":"pub fn async_attr(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.async_attr\nhtmz async_attr","url":"htmz.html#async_attr"},{"doc":"htmz","title":"attr","content":"pub fn attr(\n  el: Htmz,\n  attr_name: String,\n  attr_value: String,\n) -&gt; Htmz\n\nSynonyms:\nhtmz.attr\nhtmz attr","url":"htmz.html#attr"},{"doc":"htmz","title":"autocapitalize","content":"pub fn autocapitalize(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.autocapitalize\nhtmz autocapitalize","url":"htmz.html#autocapitalize"},{"doc":"htmz","title":"autocomplete","content":"pub fn autocomplete(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.autocomplete\nhtmz autocomplete","url":"htmz.html#autocomplete"},{"doc":"htmz","title":"autofocus","content":"pub fn autofocus(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.autofocus\nhtmz autofocus","url":"htmz.html#autofocus"},{"doc":"htmz","title":"charset","content":"pub fn charset(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.charset\nhtmz charset","url":"htmz.html#charset"},{"doc":"htmz","title":"checked","content":"pub fn checked(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.checked\nhtmz checked","url":"htmz.html#checked"},{"doc":"htmz","title":"child","content":"pub fn child(el: Htmz, child: Htmz) -&gt; Htmz\n\nSynonyms:\nhtmz.child\nhtmz child","url":"htmz.html#child"},{"doc":"htmz","title":"children","content":"pub fn children(el: Htmz, children: List(Htmz)) -&gt; Htmz\n\nSynonyms:\nhtmz.children\nhtmz children","url":"htmz.html#children"},{"doc":"htmz","title":"class","content":"pub fn class(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.class\nhtmz class","url":"htmz.html#class"},{"doc":"htmz","title":"cols","content":"pub fn cols(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.cols\nhtmz cols","url":"htmz.html#cols"},{"doc":"htmz","title":"colspan","content":"pub fn colspan(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.colspan\nhtmz colspan","url":"htmz.html#colspan"},{"doc":"htmz","title":"columngap","content":"pub fn columngap(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.columngap\nhtmz columngap","url":"htmz.html#columngap"},{"doc":"htmz","title":"content","content":"pub fn content(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.content\nhtmz content","url":"htmz.html#content"},{"doc":"htmz","title":"contenteditable","content":"pub fn contenteditable(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.contenteditable\nhtmz contenteditable","url":"htmz.html#contenteditable"},{"doc":"htmz","title":"contextmenu","content":"pub fn contextmenu(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.contextmenu\nhtmz contextmenu","url":"htmz.html#contextmenu"},{"doc":"htmz","title":"controls","content":"pub fn controls(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.controls\nhtmz controls","url":"htmz.html#controls"},{"doc":"htmz","title":"coords","content":"pub fn coords(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.coords\nhtmz coords","url":"htmz.html#coords"},{"doc":"htmz","title":"crossorigin","content":"pub fn crossorigin(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.crossorigin\nhtmz crossorigin","url":"htmz.html#crossorigin"},{"doc":"htmz","title":"data","content":"pub fn data(el: Htmz, key: String, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.data\nhtmz data","url":"htmz.html#data"},{"doc":"htmz","title":"datetime","content":"pub fn datetime(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.datetime\nhtmz datetime","url":"htmz.html#datetime"},{"doc":"htmz","title":"defer","content":"pub fn defer(el: Htmz) -&gt; Htmz\n\nSynonyms:\nhtmz.defer\nhtmz defer","url":"htmz.html#defer"},{"doc":"htmz","title":"dir","content":"pub fn dir(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.dir\nhtmz dir","url":"htmz.html#dir"},{"doc":"htmz","title":"dirname","content":"pub fn dirname(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.dirname\nhtmz dirname","url":"htmz.html#dirname"},{"doc":"htmz","title":"disabled","content":"pub fn disabled(el: Htmz) -&gt; Htmz\n\nSynonyms:\nhtmz.disabled\nhtmz disabled","url":"htmz.html#disabled"},{"doc":"htmz","title":"download","content":"pub fn download(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.download\nhtmz download","url":"htmz.html#download"},{"doc":"htmz","title":"draggable","content":"pub fn draggable(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.draggable\nhtmz draggable","url":"htmz.html#draggable"},{"doc":"htmz","title":"dropzone","content":"pub fn dropzone(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.dropzone\nhtmz dropzone","url":"htmz.html#dropzone"},{"doc":"htmz","title":"enctype","content":"pub fn enctype(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.enctype\nhtmz enctype","url":"htmz.html#enctype"},{"doc":"htmz","title":"enterkeyhint","content":"pub fn enterkeyhint(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.enterkeyhint\nhtmz enterkeyhint","url":"htmz.html#enterkeyhint"},{"doc":"htmz","title":"escape","content":"pub fn escape(content: String) -&gt; String\n\nSynonyms:\nhtmz.escape\nhtmz escape","url":"htmz.html#escape"},{"doc":"htmz","title":"for","content":"pub fn for(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.for\nhtmz for","url":"htmz.html#for"},{"doc":"htmz","title":"formaction","content":"pub fn formaction(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.formaction\nhtmz formaction","url":"htmz.html#formaction"},{"doc":"htmz","title":"formenctype","content":"pub fn formenctype(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.formenctype\nhtmz formenctype","url":"htmz.html#formenctype"},{"doc":"htmz","title":"formmethod","content":"pub fn formmethod(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.formmethod\nhtmz formmethod","url":"htmz.html#formmethod"},{"doc":"htmz","title":"formnovalidate","content":"pub fn formnovalidate(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.formnovalidate\nhtmz formnovalidate","url":"htmz.html#formnovalidate"},{"doc":"htmz","title":"formtarget","content":"pub fn formtarget(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.formtarget\nhtmz formtarget","url":"htmz.html#formtarget"},{"doc":"htmz","title":"frameborder","content":"pub fn frameborder(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.frameborder\nhtmz frameborder","url":"htmz.html#frameborder"},{"doc":"htmz","title":"headers","content":"pub fn headers(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.headers\nhtmz headers","url":"htmz.html#headers"},{"doc":"htmz","title":"height","content":"pub fn height(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.height\nhtmz height","url":"htmz.html#height"},{"doc":"htmz","title":"hidden","content":"pub fn hidden(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hidden\nhtmz hidden","url":"htmz.html#hidden"},{"doc":"htmz","title":"high","content":"pub fn high(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.high\nhtmz high","url":"htmz.html#high"},{"doc":"htmz","title":"href","content":"pub fn href(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.href\nhtmz href","url":"htmz.html#href"},{"doc":"htmz","title":"hreflang","content":"pub fn hreflang(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hreflang\nhtmz hreflang","url":"htmz.html#hreflang"},{"doc":"htmz","title":"http_equiv","content":"pub fn http_equiv(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.http_equiv\nhtmz http_equiv","url":"htmz.html#http_equiv"},{"doc":"htmz","title":"hx_boost","content":"pub fn hx_boost(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_boost\nhtmz hx_boost","url":"htmz.html#hx_boost"},{"doc":"htmz","title":"hx_confirm","content":"pub fn hx_confirm(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_confirm\nhtmz hx_confirm","url":"htmz.html#hx_confirm"},{"doc":"htmz","title":"hx_delete","content":"pub fn hx_delete(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_delete\nhtmz hx_delete","url":"htmz.html#hx_delete"},{"doc":"htmz","title":"hx_disabled_elt","content":"pub fn hx_disabled_elt(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_disabled_elt\nhtmz hx_disabled_elt","url":"htmz.html#hx_disabled_elt"},{"doc":"htmz","title":"hx_disinherit","content":"pub fn hx_disinherit(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_disinherit\nhtmz hx_disinherit","url":"htmz.html#hx_disinherit"},{"doc":"htmz","title":"hx_encoding","content":"pub fn hx_encoding(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_encoding\nhtmz hx_encoding","url":"htmz.html#hx_encoding"},{"doc":"htmz","title":"hx_ext","content":"pub fn hx_ext(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_ext\nhtmz hx_ext","url":"htmz.html#hx_ext"},{"doc":"htmz","title":"hx_get","content":"pub fn hx_get(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_get\nhtmz hx_get","url":"htmz.html#hx_get"},{"doc":"htmz","title":"hx_headers","content":"pub fn hx_headers(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_headers\nhtmz hx_headers","url":"htmz.html#hx_headers"},{"doc":"htmz","title":"hx_history","content":"pub fn hx_history(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_history\nhtmz hx_history","url":"htmz.html#hx_history"},{"doc":"htmz","title":"hx_history_elt","content":"pub fn hx_history_elt(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_history_elt\nhtmz hx_history_elt","url":"htmz.html#hx_history_elt"},{"doc":"htmz","title":"hx_include","content":"pub fn hx_include(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_include\nhtmz hx_include","url":"htmz.html#hx_include"},{"doc":"htmz","title":"hx_indicator","content":"pub fn hx_indicator(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_indicator\nhtmz hx_indicator","url":"htmz.html#hx_indicator"},{"doc":"htmz","title":"hx_on","content":"pub fn hx_on(el: Htmz, event: String, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_on\nhtmz hx_on","url":"htmz.html#hx_on"},{"doc":"htmz","title":"hx_params","content":"pub fn hx_params(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_params\nhtmz hx_params","url":"htmz.html#hx_params"},{"doc":"htmz","title":"hx_patch","content":"pub fn hx_patch(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_patch\nhtmz hx_patch","url":"htmz.html#hx_patch"},{"doc":"htmz","title":"hx_post","content":"pub fn hx_post(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_post\nhtmz hx_post","url":"htmz.html#hx_post"},{"doc":"htmz","title":"hx_push_url","content":"pub fn hx_push_url(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_push_url\nhtmz hx_push_url","url":"htmz.html#hx_push_url"},{"doc":"htmz","title":"hx_put","content":"pub fn hx_put(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_put\nhtmz hx_put","url":"htmz.html#hx_put"},{"doc":"htmz","title":"hx_select","content":"pub fn hx_select(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_select\nhtmz hx_select","url":"htmz.html#hx_select"},{"doc":"htmz","title":"hx_select_oob","content":"pub fn hx_select_oob(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_select_oob\nhtmz hx_select_oob","url":"htmz.html#hx_select_oob"},{"doc":"htmz","title":"hx_swap","content":"pub fn hx_swap(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_swap\nhtmz hx_swap","url":"htmz.html#hx_swap"},{"doc":"htmz","title":"hx_swap_oob","content":"pub fn hx_swap_oob(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_swap_oob\nhtmz hx_swap_oob","url":"htmz.html#hx_swap_oob"},{"doc":"htmz","title":"hx_sync","content":"pub fn hx_sync(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_sync\nhtmz hx_sync","url":"htmz.html#hx_sync"},{"doc":"htmz","title":"hx_target","content":"pub fn hx_target(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_target\nhtmz hx_target","url":"htmz.html#hx_target"},{"doc":"htmz","title":"hx_trigger","content":"pub fn hx_trigger(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_trigger\nhtmz hx_trigger","url":"htmz.html#hx_trigger"},{"doc":"htmz","title":"hx_vals","content":"pub fn hx_vals(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.hx_vals\nhtmz hx_vals","url":"htmz.html#hx_vals"},{"doc":"htmz","title":"id","content":"pub fn id(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.id\nhtmz id","url":"htmz.html#id"},{"doc":"htmz","title":"inputmode","content":"pub fn inputmode(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.inputmode\nhtmz inputmode","url":"htmz.html#inputmode"},{"doc":"htmz","title":"integrity","content":"pub fn integrity(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.integrity\nhtmz integrity","url":"htmz.html#integrity"},{"doc":"htmz","title":"is","content":"pub fn is(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.is\nhtmz is","url":"htmz.html#is"},{"doc":"htmz","title":"ismap","content":"pub fn ismap(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.ismap\nhtmz ismap","url":"htmz.html#ismap"},{"doc":"htmz","title":"kind","content":"pub fn kind(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.kind\nhtmz kind","url":"htmz.html#kind"},{"doc":"htmz","title":"label","content":"pub fn label(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.label\nhtmz label","url":"htmz.html#label"},{"doc":"htmz","title":"lang","content":"pub fn lang(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.lang\nhtmz lang","url":"htmz.html#lang"},{"doc":"htmz","title":"language","content":"pub fn language(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.language\nhtmz language","url":"htmz.html#language"},{"doc":"htmz","title":"list","content":"pub fn list(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.list\nhtmz list","url":"htmz.html#list"},{"doc":"htmz","title":"loop_attr","content":"pub fn loop_attr(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.loop_attr\nhtmz loop_attr","url":"htmz.html#loop_attr"},{"doc":"htmz","title":"low","content":"pub fn low(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.low\nhtmz low","url":"htmz.html#low"},{"doc":"htmz","title":"max","content":"pub fn max(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.max\nhtmz max","url":"htmz.html#max"},{"doc":"htmz","title":"maxlength","content":"pub fn maxlength(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.maxlength\nhtmz maxlength","url":"htmz.html#maxlength"},{"doc":"htmz","title":"method","content":"pub fn method(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.method\nhtmz method","url":"htmz.html#method"},{"doc":"htmz","title":"min","content":"pub fn min(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.min\nhtmz min","url":"htmz.html#min"},{"doc":"htmz","title":"minlength","content":"pub fn minlength(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.minlength\nhtmz minlength","url":"htmz.html#minlength"},{"doc":"htmz","title":"multiple","content":"pub fn multiple(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.multiple\nhtmz multiple","url":"htmz.html#multiple"},{"doc":"htmz","title":"name","content":"pub fn name(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.name\nhtmz name","url":"htmz.html#name"},{"doc":"htmz","title":"nothing","content":"pub fn nothing(el: Htmz) -&gt; Htmz\n\nSynonyms:\nhtmz.nothing\nhtmz nothing","url":"htmz.html#nothing"},{"doc":"htmz","title":"novalidate","content":"pub fn novalidate(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.novalidate\nhtmz novalidate","url":"htmz.html#novalidate"},{"doc":"htmz","title":"on","content":"pub fn on(el: Htmz, event: String, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.on\nhtmz on","url":"htmz.html#on"},{"doc":"htmz","title":"open","content":"pub fn open(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.open\nhtmz open","url":"htmz.html#open"},{"doc":"htmz","title":"pattern","content":"pub fn pattern(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.pattern\nhtmz pattern","url":"htmz.html#pattern"},{"doc":"htmz","title":"placeholder","content":"pub fn placeholder(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.placeholder\nhtmz placeholder","url":"htmz.html#placeholder"},{"doc":"htmz","title":"poster","content":"pub fn poster(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.poster\nhtmz poster","url":"htmz.html#poster"},{"doc":"htmz","title":"preload","content":"pub fn preload(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.preload\nhtmz preload","url":"htmz.html#preload"},{"doc":"htmz","title":"readonly","content":"pub fn readonly(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.readonly\nhtmz readonly","url":"htmz.html#readonly"},{"doc":"htmz","title":"rel","content":"pub fn rel(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.rel\nhtmz rel","url":"htmz.html#rel"},{"doc":"htmz","title":"remove_attr","content":"pub fn remove_attr(el: Htmz, attr_name: String) -&gt; Htmz\n\nSynonyms:\nhtmz.remove_attr\nhtmz remove_attr","url":"htmz.html#remove_attr"},{"doc":"htmz","title":"required","content":"pub fn required(el: Htmz) -&gt; Htmz\n\nSynonyms:\nhtmz.required\nhtmz required","url":"htmz.html#required"},{"doc":"htmz","title":"reversed","content":"pub fn reversed(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.reversed\nhtmz reversed","url":"htmz.html#reversed"},{"doc":"htmz","title":"rows","content":"pub fn rows(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.rows\nhtmz rows","url":"htmz.html#rows"},{"doc":"htmz","title":"rowspan","content":"pub fn rowspan(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.rowspan\nhtmz rowspan","url":"htmz.html#rowspan"},{"doc":"htmz","title":"sandbox","content":"pub fn sandbox(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.sandbox\nhtmz sandbox","url":"htmz.html#sandbox"},{"doc":"htmz","title":"scope","content":"pub fn scope(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.scope\nhtmz scope","url":"htmz.html#scope"},{"doc":"htmz","title":"selected","content":"pub fn selected(el: Htmz) -&gt; Htmz\n\nSynonyms:\nhtmz.selected\nhtmz selected","url":"htmz.html#selected"},{"doc":"htmz","title":"shape","content":"pub fn shape(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.shape\nhtmz shape","url":"htmz.html#shape"},{"doc":"htmz","title":"size","content":"pub fn size(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.size\nhtmz size","url":"htmz.html#size"},{"doc":"htmz","title":"sizes","content":"pub fn sizes(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.sizes\nhtmz sizes","url":"htmz.html#sizes"},{"doc":"htmz","title":"slot","content":"pub fn slot(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.slot\nhtmz slot","url":"htmz.html#slot"},{"doc":"htmz","title":"spellcheck","content":"pub fn spellcheck(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.spellcheck\nhtmz spellcheck","url":"htmz.html#spellcheck"},{"doc":"htmz","title":"src","content":"pub fn src(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.src\nhtmz src","url":"htmz.html#src"},{"doc":"htmz","title":"srcdoc","content":"pub fn srcdoc(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.srcdoc\nhtmz srcdoc","url":"htmz.html#srcdoc"},{"doc":"htmz","title":"srclang","content":"pub fn srclang(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.srclang\nhtmz srclang","url":"htmz.html#srclang"},{"doc":"htmz","title":"start","content":"pub fn start(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.start\nhtmz start","url":"htmz.html#start"},{"doc":"htmz","title":"step","content":"pub fn step(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.step\nhtmz step","url":"htmz.html#step"},{"doc":"htmz","title":"style","content":"pub fn style(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.style\nhtmz style","url":"htmz.html#style"},{"doc":"htmz","title":"tabindex","content":"pub fn tabindex(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.tabindex\nhtmz tabindex","url":"htmz.html#tabindex"},{"doc":"htmz","title":"target","content":"pub fn target(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.target\nhtmz target","url":"htmz.html#target"},{"doc":"htmz","title":"text","content":"pub fn text(el: Htmz, text: String) -&gt; Htmz\n\nSynonyms:\nhtmz.text\nhtmz text","url":"htmz.html#text"},{"doc":"htmz","title":"title","content":"pub fn title(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.title\nhtmz title","url":"htmz.html#title"},{"doc":"htmz","title":"to_string","content":"pub fn to_string(el: Htmz) -&gt; String\n\nSynonyms:\nhtmz.to_string\nhtmz to_string","url":"htmz.html#to_string"},{"doc":"htmz","title":"translate","content":"pub fn translate(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.translate\nhtmz translate","url":"htmz.html#translate"},{"doc":"htmz","title":"type_","content":"pub fn type_(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.type_\nhtmz type_","url":"htmz.html#type_"},{"doc":"htmz","title":"usemap","content":"pub fn usemap(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.usemap\nhtmz usemap","url":"htmz.html#usemap"},{"doc":"htmz","title":"value","content":"pub fn value(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.value\nhtmz value","url":"htmz.html#value"},{"doc":"htmz","title":"width","content":"pub fn width(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.width\nhtmz width","url":"htmz.html#width"},{"doc":"htmz","title":"wrap","content":"pub fn wrap(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.wrap\nhtmz wrap","url":"htmz.html#wrap"},{"doc":"htmz","title":"x_bind","content":"pub fn x_bind(el: Htmz, field: String, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_bind\nhtmz x_bind","url":"htmz.html#x_bind"},{"doc":"htmz","title":"x_cloak","content":"pub fn x_cloak(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_cloak\nhtmz x_cloak","url":"htmz.html#x_cloak"},{"doc":"htmz","title":"x_data","content":"pub fn x_data(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_data\nhtmz x_data","url":"htmz.html#x_data"},{"doc":"htmz","title":"x_effect","content":"pub fn x_effect(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_effect\nhtmz x_effect","url":"htmz.html#x_effect"},{"doc":"htmz","title":"x_for","content":"pub fn x_for(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_for\nhtmz x_for","url":"htmz.html#x_for"},{"doc":"htmz","title":"x_html","content":"pub fn x_html(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_html\nhtmz x_html","url":"htmz.html#x_html"},{"doc":"htmz","title":"x_id","content":"pub fn x_id(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_id\nhtmz x_id","url":"htmz.html#x_id"},{"doc":"htmz","title":"x_if","content":"pub fn x_if(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_if\nhtmz x_if","url":"htmz.html#x_if"},{"doc":"htmz","title":"x_ignore","content":"pub fn x_ignore(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_ignore\nhtmz x_ignore","url":"htmz.html#x_ignore"},{"doc":"htmz","title":"x_init","content":"pub fn x_init(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_init\nhtmz x_init","url":"htmz.html#x_init"},{"doc":"htmz","title":"x_model","content":"pub fn x_model(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_model\nhtmz x_model","url":"htmz.html#x_model"},{"doc":"htmz","title":"x_modelable","content":"pub fn x_modelable(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_modelable\nhtmz x_modelable","url":"htmz.html#x_modelable"},{"doc":"htmz","title":"x_on","content":"pub fn x_on(el: Htmz, event: String, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_on\nhtmz x_on","url":"htmz.html#x_on"},{"doc":"htmz","title":"x_ref","content":"pub fn x_ref(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_ref\nhtmz x_ref","url":"htmz.html#x_ref"},{"doc":"htmz","title":"x_show","content":"pub fn x_show(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_show\nhtmz x_show","url":"htmz.html#x_show"},{"doc":"htmz","title":"x_teleport","content":"pub fn x_teleport(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_teleport\nhtmz x_teleport","url":"htmz.html#x_teleport"},{"doc":"htmz","title":"x_text","content":"pub fn x_text(el: Htmz, value: String) -&gt; Htmz\n\nSynonyms:\nhtmz.x_text\nhtmz x_text","url":"htmz.html#x_text"},{"doc":"htmz","title":"x_transition","content":"pub fn x_transition(el: Htmz) -&gt; Htmz\n\nSynonyms:\nhtmz.x_transition\nhtmz x_transition","url":"htmz.html#x_transition"},{"doc":"htmz","title":"x_transition_a","content":"pub fn x_transition_a(\n  el: Htmz,\n  modifier: String,\n  value: String,\n) -&gt; Htmz\n\nSynonyms:\nhtmz.x_transition_a\nhtmz x_transition_a","url":"htmz.html#x_transition_a"},{"doc":"htmz","title":"htmz","content":"","url":"htmz.html"}]);